local ADDON = ...

GMEXP_LONGNRFMT = true

local string_format = string.format
local number = function(v)

	if GMEXP_LONGNRFMT then return v end

	if v <= 9999 then return v	
	elseif v >= 1000000 then return format("%.1fM", v/1000000)
	elseif v >= 10000 then return format("%.1fK", v/1000)
	end
	
end

local multi = {
    25, 50, 90, 140, 200,
    275, 375, 500, 650, 850,
    1100, 1400, 1775, 2250, 2850,
    3600, 4550, 5700, 7200, 9000,
    11300, 14200, 17800, 22300, 24900,
	100000, 130000,170000,220000,290000,
	380000,490000,640000,830000,1080000,
	1400000,1820000,2370000,3080000,4000000,
	5200000,6760000,8790000,11430000,14860000,
	19320000,25120000,32660000,42460000,55200000
};



local ldb = LibStub:GetLibrary("LibDataBroker-1.1")
local dataobj = ldb:NewDataObject("gmXp", {
	type = "data source",
	icon = "Interface\\Addons\\"..ADDON.."\\icon.tga",
	text = "-",
})

local frame = CreateFrame("Frame")
frame:RegisterEvent("PLAYER_ENTERING_WORLD")
frame:RegisterEvent("PLAYER_XP_UPDATE")
frame:RegisterEvent("ARTIFACT_XP_UPDATE")
frame:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")

frame:SetScript("OnEvent", function(self, event, ...)

	if UnitLevel("player") == GetMaxPlayerLevel() then 
	
		if HasArtifactEquipped() then 
			local artifactItemID, _, _, _, ArtPower, ArtPointsSpent, _, _, _, _, _, _, artifactTier = C_ArtifactUI.GetEquippedArtifactInfo();
			dataobj.text = string_format("A:%s %.1f%%", ArtPointsSpent, ArtPower/C_ArtifactUI.GetCostForPointAtRank(ArtPointsSpent,artifactTier)*100)
		else 
			dataobj.text = "L: " .. UnitLevel("player")		
		end
	
	else	
		dataobj.text = string_format("L:%s %.1f%%", UnitLevel("player"), UnitXP("player")/UnitXPMax("player")*100)	
	end
	
end)	

dataobj.OnClick = function(self, button)  

		GMEXP_LONGNRFMT = not GMEXP_LONGNRFMT

end

function dataobj.OnTooltipShow(tooltip)

	tooltip:AddLine(ADDON)
	tooltip:AddLine(" ")
	
	if UnitLevel("player") == GetMaxPlayerLevel() then
		
		tooltip:AddDoubleLine("Max content level", UnitLevel("player"), 1, 1, 1, 0, 1, 0)		

	else
	
		tooltip:AddDoubleLine("Level", UnitLevel("player"), 1, 1, 1, 0, 1, 0)
		tooltip:AddDoubleLine("Current XP", UnitXP("player"), 1, 1, 1, 0, 1, 0)
		tooltip:AddDoubleLine("Remaining XP", UnitXPMax("player") - UnitXP("player"), 1, 1, 1, 1, 0, 0)
		tooltip:AddDoubleLine("Progress in this level", string_format("%.1f%%", UnitXP("player")/UnitXPMax("player")*100) , 1, 1, 1, 0, 1, 0)
		tooltip:AddDoubleLine("Remaining rested", GetXPExhaustion() or 0, 1, 1, 1, 0, 1, 0)

	end
	
	if HasArtifactEquipped() then 
		
		local _, _, ArtName,ArtIcon,ArtPower,ArtPointsSpent ,  _, _, _, _, _, _, artifactTier = C_ArtifactUI.GetEquippedArtifactInfo();
		local ArtNextRank=C_ArtifactUI.GetCostForPointAtRank(ArtPointsSpent,artifactTier)
		local kl = select(2,GetCurrencyInfo(1171))
		local km = multi[kl] or 0
		local delta = ArtNextRank-ArtPower
	
		tooltip:AddLine(" ")
		tooltip:AddDoubleLine("Artifact", ArtName,1, 1, 1, 0, 1, 1)
		tooltip:AddDoubleLine("Rank", number(ArtPointsSpent), 1, 1, 1, 0, 1, 0)
		tooltip:AddDoubleLine("Power",number(ArtPower), 1, 1, 1, 0, 1, 0)

		if (delta) >= 0 then 
			tooltip:AddDoubleLine("Power to next rank",number(delta), 1, 1, 1, 1, 0, 0)
		else
			tooltip:AddDoubleLine("Power in excess in rank",number(abs(delta)), 1, 1, 1, 1, 1, 0)				
		end

		tooltip:AddDoubleLine("Progress in rank", string_format("%.1f%%", ArtPower/ArtNextRank*100) , 1, 1, 1, 0, 1, 0)
		tooltip:AddLine(" ")
		tooltip:AddDoubleLine("Knownledge level", kl,1, 1, 1, 0, 1, 0)
		tooltip:AddDoubleLine("Knownledge multiplier", km .."%" ,1, 1, 1, 0, 1, 0)
		tooltip:AddLine(" ")
		if GMEXP_LONGNRFMT == true then 
			tooltip:AddDoubleLine("Click changes to:", "Short Numbers",1, 1, 1, 1, 1, 0)
		else
			tooltip:AddDoubleLine("Click changes to:", "Long Numbers",1, 1, 1, 0, 1, 1)
		end
	end	
		
end
